==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/EdifactAcknowledgementSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.EdifactAcknowledgementSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The Edifact agreement acknowledgement settings.
 * @property acknowledgementControlNumberLowerBound The acknowledgement control number lower bound.
 * @property acknowledgementControlNumberPrefix The acknowledgement control number prefix.
 * @property acknowledgementControlNumberSuffix The acknowledgement control number suffix.
 * @property acknowledgementControlNumberUpperBound The acknowledgement control number upper bound.
 * @property batchFunctionalAcknowledgements The value indicating whether to batch functional acknowledgements.
 * @property batchTechnicalAcknowledgements The value indicating whether to batch the technical acknowledgements.
 * @property needFunctionalAcknowledgement The value indicating whether functional acknowledgement is needed.
 * @property needLoopForValidMessages The value indicating whether a loop is needed for valid messages.
 * @property needTechnicalAcknowledgement The value indicating whether technical acknowledgement is needed.
 * @property rolloverAcknowledgementControlNumber The value indicating whether to rollover acknowledgement control number.
 * @property sendSynchronousAcknowledgement The value indicating whether to send synchronous acknowledgement.
 */
public data class EdifactAcknowledgementSettingsArgs(
    public val acknowledgementControlNumberLowerBound: Output<Int>,
    public val acknowledgementControlNumberPrefix: Output<String>? = null,
    public val acknowledgementControlNumberSuffix: Output<String>? = null,
    public val acknowledgementControlNumberUpperBound: Output<Int>,
    public val batchFunctionalAcknowledgements: Output<Boolean>,
    public val batchTechnicalAcknowledgements: Output<Boolean>,
    public val needFunctionalAcknowledgement: Output<Boolean>,
    public val needLoopForValidMessages: Output<Boolean>,
    public val needTechnicalAcknowledgement: Output<Boolean>,
    public val rolloverAcknowledgementControlNumber: Output<Boolean>,
    public val sendSynchronousAcknowledgement: Output<Boolean>,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.EdifactAcknowledgementSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.EdifactAcknowledgementSettingsArgs =
        com.pulumi.azurenative.logic.inputs.EdifactAcknowledgementSettingsArgs.builder()
            .acknowledgementControlNumberLowerBound(
                acknowledgementControlNumberLowerBound.applyValue({ args0 ->
                    args0
                }),
            )
            .acknowledgementControlNumberPrefix(
                acknowledgementControlNumberPrefix?.applyValue({ args0 ->
                    args0
                }),
            )
            .acknowledgementControlNumberSuffix(
                acknowledgementControlNumberSuffix?.applyValue({ args0 ->
                    args0
                }),
            )
            .acknowledgementControlNumberUpperBound(
                acknowledgementControlNumberUpperBound.applyValue({ args0 ->
                    args0
                }),
            )
            .batchFunctionalAcknowledgements(batchFunctionalAcknowledgements.applyValue({ args0 -> args0 }))
            .batchTechnicalAcknowledgements(batchTechnicalAcknowledgements.applyValue({ args0 -> args0 }))
            .needFunctionalAcknowledgement(needFunctionalAcknowledgement.applyValue({ args0 -> args0 }))
            .needLoopForValidMessages(needLoopForValidMessages.applyValue({ args0 -> args0 }))
            .needTechnicalAcknowledgement(needTechnicalAcknowledgement.applyValue({ args0 -> args0 }))
            .rolloverAcknowledgementControlNumber(
                rolloverAcknowledgementControlNumber.applyValue({ args0 ->
                    args0
                }),
            )
            .sendSynchronousAcknowledgement(
                sendSynchronousAcknowledgement.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [EdifactAcknowledgementSettingsArgs].
 */
@PulumiTagMarker
public class EdifactAcknowledgementSettingsArgsBuilder internal constructor() {
    private var acknowledgementControlNumberLowerBound: Output<Int>? = null

    private var acknowledgementControlNumberPrefix: Output<String>? = null

    private var acknowledgementControlNumberSuffix: Output<String>? = null

    private var acknowledgementControlNumberUpperBound: Output<Int>? = null

    private var batchFunctionalAcknowledgements: Output<Boolean>? = null

    private var batchTechnicalAcknowledgements: Output<Boolean>? = null

    private var needFunctionalAcknowledgement: Output<Boolean>? = null

    private var needLoopForValidMessages: Output<Boolean>? = null

    private var needTechnicalAcknowledgement: Output<Boolean>? = null

    private var rolloverAcknowledgementControlNumber: Output<Boolean>? = null

    private var sendSynchronousAcknowledgement: Output<Boolean>? = null

    /**
     * @param value The acknowledgement control number lower bound.
     */
    @JvmName("owiteiqtlfdsfnhm")
    public suspend fun acknowledgementControlNumberLowerBound(`value`: Output<Int>) {
        this.acknowledgementControlNumberLowerBound = value
    }

    /**
     * @param value The acknowledgement control number prefix.
     */
    @JvmName("irioghosaxhamglf")
    public suspend fun acknowledgementControlNumberPrefix(`value`: Output<String>) {
        this.acknowledgementControlNumberPrefix = value
    }

    /**
     * @param value The acknowledgement control number suffix.
     */
    @JvmName("pirevqscbxaoansh")
    public suspend fun acknowledgementControlNumberSuffix(`value`: Output<String>) {
        this.acknowledgementControlNumberSuffix = value
    }

    /**
     * @param value The acknowledgement control number upper bound.
     */
    @JvmName("jpjiewxaimyobvtv")
    public suspend fun acknowledgementControlNumberUpperBound(`value`: Output<Int>) {
        this.acknowledgementControlNumberUpperBound = value
    }

    /**
     * @param value The value indicating whether to batch functional acknowledgements.
     */
    @JvmName("lkwuecidlnycarbs")
    public suspend fun batchFunctionalAcknowledgements(`value`: Output<Boolean>) {
        this.batchFunctionalAcknowledgements = value
    }

    /**
     * @param value The value indicating whether to batch the technical acknowledgements.
     */
    @JvmName("jksfjngeracolthi")
    public suspend fun batchTechnicalAcknowledgements(`value`: Output<Boolean>) {
        this.batchTechnicalAcknowledgements = value
    }

    /**
     * @param value The value indicating whether functional acknowledgement is needed.
     */
    @JvmName("bhesofpntxcjenqf")
    public suspend fun needFunctionalAcknowledgement(`value`: Output<Boolean>) {
        this.needFunctionalAcknowledgement = value
    }

    /**
     * @param value The value indicating whether a loop is needed for valid messages.
     */
    @JvmName("ijslpgelmjpppume")
    public suspend fun needLoopForValidMessages(`value`: Output<Boolean>) {
        this.needLoopForValidMessages = value
    }

    /**
     * @param value The value indicating whether technical acknowledgement is needed.
     */
    @JvmName("brmpyponuprohbml")
    public suspend fun needTechnicalAcknowledgement(`value`: Output<Boolean>) {
        this.needTechnicalAcknowledgement = value
    }

    /**
     * @param value The value indicating whether to rollover acknowledgement control number.
     */
    @JvmName("yoingujsgystgwgt")
    public suspend fun rolloverAcknowledgementControlNumber(`value`: Output<Boolean>) {
        this.rolloverAcknowledgementControlNumber = value
    }

    /**
     * @param value The value indicating whether to send synchronous acknowledgement.
     */
    @JvmName("xwfsikjupumvyrig")
    public suspend fun sendSynchronousAcknowledgement(`value`: Output<Boolean>) {
        this.sendSynchronousAcknowledgement = value
    }

    /**
     * @param value The acknowledgement control number lower bound.
     */
    @JvmName("otwcdirlhjkjxldi")
    public suspend fun acknowledgementControlNumberLowerBound(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.acknowledgementControlNumberLowerBound = mapped
    }

    /**
     * @param value The acknowledgement control number prefix.
     */
    @JvmName("gtcucxkfhweilqgg")
    public suspend fun acknowledgementControlNumberPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.acknowledgementControlNumberPrefix = mapped
    }

    /**
     * @param value The acknowledgement control number suffix.
     */
    @JvmName("ehsauwcdriwdcftw")
    public suspend fun acknowledgementControlNumberSuffix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.acknowledgementControlNumberSuffix = mapped
    }

    /**
     * @param value The acknowledgement control number upper bound.
     */
    @JvmName("rhvbyjxmlqgqpgmm")
    public suspend fun acknowledgementControlNumberUpperBound(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.acknowledgementControlNumberUpperBound = mapped
    }

    /**
     * @param value The value indicating whether to batch functional acknowledgements.
     */
    @JvmName("bxokiygkdpakobsx")
    public suspend fun batchFunctionalAcknowledgements(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.batchFunctionalAcknowledgements = mapped
    }

    /**
     * @param value The value indicating whether to batch the technical acknowledgements.
     */
    @JvmName("wdpkjdngshpiamrc")
    public suspend fun batchTechnicalAcknowledgements(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.batchTechnicalAcknowledgements = mapped
    }

    /**
     * @param value The value indicating whether functional acknowledgement is needed.
     */
    @JvmName("warbrdddpjcdjmge")
    public suspend fun needFunctionalAcknowledgement(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.needFunctionalAcknowledgement = mapped
    }

    /**
     * @param value The value indicating whether a loop is needed for valid messages.
     */
    @JvmName("xcfhkdhempvhftcg")
    public suspend fun needLoopForValidMessages(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.needLoopForValidMessages = mapped
    }

    /**
     * @param value The value indicating whether technical acknowledgement is needed.
     */
    @JvmName("gelefrparijkoqrh")
    public suspend fun needTechnicalAcknowledgement(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.needTechnicalAcknowledgement = mapped
    }

    /**
     * @param value The value indicating whether to rollover acknowledgement control number.
     */
    @JvmName("edewljswvhijpuye")
    public suspend fun rolloverAcknowledgementControlNumber(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rolloverAcknowledgementControlNumber = mapped
    }

    /**
     * @param value The value indicating whether to send synchronous acknowledgement.
     */
    @JvmName("knqsiftlfqmpdjws")
    public suspend fun sendSynchronousAcknowledgement(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sendSynchronousAcknowledgement = mapped
    }

    internal fun build(): EdifactAcknowledgementSettingsArgs = EdifactAcknowledgementSettingsArgs(
        acknowledgementControlNumberLowerBound = acknowledgementControlNumberLowerBound ?: throw
            PulumiNullFieldException("acknowledgementControlNumberLowerBound"),
        acknowledgementControlNumberPrefix = acknowledgementControlNumberPrefix,
        acknowledgementControlNumberSuffix = acknowledgementControlNumberSuffix,
        acknowledgementControlNumberUpperBound = acknowledgementControlNumberUpperBound ?: throw
            PulumiNullFieldException("acknowledgementControlNumberUpperBound"),
        batchFunctionalAcknowledgements = batchFunctionalAcknowledgements ?: throw
            PulumiNullFieldException("batchFunctionalAcknowledgements"),
        batchTechnicalAcknowledgements = batchTechnicalAcknowledgements ?: throw
            PulumiNullFieldException("batchTechnicalAcknowledgements"),
        needFunctionalAcknowledgement = needFunctionalAcknowledgement ?: throw
            PulumiNullFieldException("needFunctionalAcknowledgement"),
        needLoopForValidMessages = needLoopForValidMessages ?: throw
            PulumiNullFieldException("needLoopForValidMessages"),
        needTechnicalAcknowledgement = needTechnicalAcknowledgement ?: throw
            PulumiNullFieldException("needTechnicalAcknowledgement"),
        rolloverAcknowledgementControlNumber = rolloverAcknowledgementControlNumber ?: throw
            PulumiNullFieldException("rolloverAcknowledgementControlNumber"),
        sendSynchronousAcknowledgement = sendSynchronousAcknowledgement ?: throw
            PulumiNullFieldException("sendSynchronousAcknowledgement"),
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/EdifactAcknowledgementSettingsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.EdifactAcknowledgementSettingsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Boolean
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The Edifact agreement acknowledgement settings.
 * @property acknowledgementControlNumberLowerBound The acknowledgement control number lower bound.
 * @property acknowledgementControlNumberPrefix The acknowledgement control number prefix.
 * @property acknowledgementControlNumberSuffix The acknowledgement control number suffix.
 * @property acknowledgementControlNumberUpperBound The acknowledgement control number upper bound.
 * @property batchFunctionalAcknowledgements The value indicating whether to batch functional acknowledgements.
 * @property batchTechnicalAcknowledgements The value indicating whether to batch the technical acknowledgements.
 * @property needFunctionalAcknowledgement The value indicating whether functional acknowledgement is needed.
 * @property needLoopForValidMessages The value indicating whether a loop is needed for valid messages.
 * @property needTechnicalAcknowledgement The value indicating whether technical acknowledgement is needed.
 * @property rolloverAcknowledgementControlNumber The value indicating whether to rollover acknowledgement control number.
 * @property sendSynchronousAcknowledgement The value indicating whether to send synchronous acknowledgement.
 */
public data class EdifactAcknowledgementSettingsArgs(
    public val acknowledgementControlNumberLowerBound: Output<Int>,
    public val acknowledgementControlNumberPrefix: Output<String>? = null,
    public val acknowledgementControlNumberSuffix: Output<String>? = null,
    public val acknowledgementControlNumberUpperBound: Output<Int>,
    public val batchFunctionalAcknowledgements: Output<Boolean>,
    public val batchTechnicalAcknowledgements: Output<Boolean>,
    public val needFunctionalAcknowledgement: Output<Boolean>,
    public val needLoopForValidMessages: Output<Boolean>,
    public val needTechnicalAcknowledgement: Output<Boolean>,
    public val rolloverAcknowledgementControlNumber: Output<Boolean>,
    public val sendSynchronousAcknowledgement: Output<Boolean>,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.EdifactAcknowledgementSettingsArgs> {
    override fun toJava(): com.pulumi.azurenative.logic.inputs.EdifactAcknowledgementSettingsArgs =
        com.pulumi.azurenative.logic.inputs.EdifactAcknowledgementSettingsArgs.builder()
            .acknowledgementControlNumberLowerBound(
                acknowledgementControlNumberLowerBound.applyValue({ args0 ->
                    args0
                }),
            )
            .acknowledgementControlNumberPrefix(
                acknowledgementControlNumberPrefix?.applyValue({ args0 ->
                    args0
                }),
            )
            .acknowledgementControlNumberSuffix(
                acknowledgementControlNumberSuffix?.applyValue({ args0 ->
                    args0
                }),
            )
            .acknowledgementControlNumberUpperBound(
                acknowledgementControlNumberUpperBound.applyValue({ args0 ->
                    args0
                }),
            )
            .batchFunctionalAcknowledgements(batchFunctionalAcknowledgements.applyValue({ args0 -> args0 }))
            .batchTechnicalAcknowledgements(batchTechnicalAcknowledgements.applyValue({ args0 -> args0 }))
            .needFunctionalAcknowledgement(needFunctionalAcknowledgement.applyValue({ args0 -> args0 }))
            .needLoopForValidMessages(needLoopForValidMessages.applyValue({ args0 -> args0 }))
            .needTechnicalAcknowledgement(needTechnicalAcknowledgement.applyValue({ args0 -> args0 }))
            .rolloverAcknowledgementControlNumber(
                rolloverAcknowledgementControlNumber.applyValue({ args0 ->
                    args0
                }),
            )
            .sendSynchronousAcknowledgement(
                sendSynchronousAcknowledgement.applyValue({ args0 ->
                    args0
                }),
            ).build()
}

/**
 * Builder for [EdifactAcknowledgementSettingsArgs].
 */
@PulumiTagMarker
public class EdifactAcknowledgementSettingsArgsBuilder internal constructor() {
    private var acknowledgementControlNumberLowerBound: Output<Int>? = null

    private var acknowledgementControlNumberPrefix: Output<String>? = null

    private var acknowledgementControlNumberSuffix: Output<String>? = null

    private var acknowledgementControlNumberUpperBound: Output<Int>? = null

    private var batchFunctionalAcknowledgements: Output<Boolean>? = null

    private var batchTechnicalAcknowledgements: Output<Boolean>? = null

    private var needFunctionalAcknowledgement: Output<Boolean>? = null

    private var needLoopForValidMessages: Output<Boolean>? = null

    private var needTechnicalAcknowledgement: Output<Boolean>? = null

    private var rolloverAcknowledgementControlNumber: Output<Boolean>? = null

    private var sendSynchronousAcknowledgement: Output<Boolean>? = null

    /**
     * @param value The acknowledgement control number lower bound.
     */
    @JvmName("gcyxjwxmgnyaxoup")
    public suspend fun acknowledgementControlNumberLowerBound(`value`: Output<Int>) {
        this.acknowledgementControlNumberLowerBound = value
    }

    /**
     * @param value The acknowledgement control number prefix.
     */
    @JvmName("jmshxtjmicyotscs")
    public suspend fun acknowledgementControlNumberPrefix(`value`: Output<String>) {
        this.acknowledgementControlNumberPrefix = value
    }

    /**
     * @param value The acknowledgement control number suffix.
     */
    @JvmName("dctiskecijwblyvx")
    public suspend fun acknowledgementControlNumberSuffix(`value`: Output<String>) {
        this.acknowledgementControlNumberSuffix = value
    }

    /**
     * @param value The acknowledgement control number upper bound.
     */
    @JvmName("cdmstudpfeyeduak")
    public suspend fun acknowledgementControlNumberUpperBound(`value`: Output<Int>) {
        this.acknowledgementControlNumberUpperBound = value
    }

    /**
     * @param value The value indicating whether to batch functional acknowledgements.
     */
    @JvmName("idbaslkkjsglnaei")
    public suspend fun batchFunctionalAcknowledgements(`value`: Output<Boolean>) {
        this.batchFunctionalAcknowledgements = value
    }

    /**
     * @param value The value indicating whether to batch the technical acknowledgements.
     */
    @JvmName("rnssvxhpemrohcsw")
    public suspend fun batchTechnicalAcknowledgements(`value`: Output<Boolean>) {
        this.batchTechnicalAcknowledgements = value
    }

    /**
     * @param value The value indicating whether functional acknowledgement is needed.
     */
    @JvmName("iebtrqfextrbkswe")
    public suspend fun needFunctionalAcknowledgement(`value`: Output<Boolean>) {
        this.needFunctionalAcknowledgement = value
    }

    /**
     * @param value The value indicating whether a loop is needed for valid messages.
     */
    @JvmName("bktgebuhpdmdlcex")
    public suspend fun needLoopForValidMessages(`value`: Output<Boolean>) {
        this.needLoopForValidMessages = value
    }

    /**
     * @param value The value indicating whether technical acknowledgement is needed.
     */
    @JvmName("nfcwhymhyqaupvlr")
    public suspend fun needTechnicalAcknowledgement(`value`: Output<Boolean>) {
        this.needTechnicalAcknowledgement = value
    }

    /**
     * @param value The value indicating whether to rollover acknowledgement control number.
     */
    @JvmName("stfrpfrtmlywttjq")
    public suspend fun rolloverAcknowledgementControlNumber(`value`: Output<Boolean>) {
        this.rolloverAcknowledgementControlNumber = value
    }

    /**
     * @param value The value indicating whether to send synchronous acknowledgement.
     */
    @JvmName("jcvucjaqvhdxvqbk")
    public suspend fun sendSynchronousAcknowledgement(`value`: Output<Boolean>) {
        this.sendSynchronousAcknowledgement = value
    }

    /**
     * @param value The acknowledgement control number lower bound.
     */
    @JvmName("nhxkmqtwpxdlihoy")
    public suspend fun acknowledgementControlNumberLowerBound(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.acknowledgementControlNumberLowerBound = mapped
    }

    /**
     * @param value The acknowledgement control number prefix.
     */
    @JvmName("xusrkynkomtwnfek")
    public suspend fun acknowledgementControlNumberPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.acknowledgementControlNumberPrefix = mapped
    }

    /**
     * @param value The acknowledgement control number suffix.
     */
    @JvmName("hvkfmyycmsalrdek")
    public suspend fun acknowledgementControlNumberSuffix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.acknowledgementControlNumberSuffix = mapped
    }

    /**
     * @param value The acknowledgement control number upper bound.
     */
    @JvmName("xajjbrjmtklvrwuu")
    public suspend fun acknowledgementControlNumberUpperBound(`value`: Int) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.acknowledgementControlNumberUpperBound = mapped
    }

    /**
     * @param value The value indicating whether to batch functional acknowledgements.
     */
    @JvmName("fdeotuuqksgatpel")
    public suspend fun batchFunctionalAcknowledgements(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.batchFunctionalAcknowledgements = mapped
    }

    /**
     * @param value The value indicating whether to batch the technical acknowledgements.
     */
    @JvmName("xhgqjyhbciborfqq")
    public suspend fun batchTechnicalAcknowledgements(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.batchTechnicalAcknowledgements = mapped
    }

    /**
     * @param value The value indicating whether functional acknowledgement is needed.
     */
    @JvmName("skywrbylqcbvpxix")
    public suspend fun needFunctionalAcknowledgement(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.needFunctionalAcknowledgement = mapped
    }

    /**
     * @param value The value indicating whether a loop is needed for valid messages.
     */
    @JvmName("mrfqtfuutmemybno")
    public suspend fun needLoopForValidMessages(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.needLoopForValidMessages = mapped
    }

    /**
     * @param value The value indicating whether technical acknowledgement is needed.
     */
    @JvmName("uambujnorwniudcc")
    public suspend fun needTechnicalAcknowledgement(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.needTechnicalAcknowledgement = mapped
    }

    /**
     * @param value The value indicating whether to rollover acknowledgement control number.
     */
    @JvmName("ncmppjpabyiupebg")
    public suspend fun rolloverAcknowledgementControlNumber(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.rolloverAcknowledgementControlNumber = mapped
    }

    /**
     * @param value The value indicating whether to send synchronous acknowledgement.
     */
    @JvmName("cuydpkxwmvbqhpjl")
    public suspend fun sendSynchronousAcknowledgement(`value`: Boolean) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sendSynchronousAcknowledgement = mapped
    }

    internal fun build(): EdifactAcknowledgementSettingsArgs = EdifactAcknowledgementSettingsArgs(
        acknowledgementControlNumberLowerBound = acknowledgementControlNumberLowerBound ?: throw
            PulumiNullFieldException("acknowledgementControlNumberLowerBound"),
        acknowledgementControlNumberPrefix = acknowledgementControlNumberPrefix,
        acknowledgementControlNumberSuffix = acknowledgementControlNumberSuffix,
        acknowledgementControlNumberUpperBound = acknowledgementControlNumberUpperBound ?: throw
            PulumiNullFieldException("acknowledgementControlNumberUpperBound"),
        batchFunctionalAcknowledgements = batchFunctionalAcknowledgements ?: throw
            PulumiNullFieldException("batchFunctionalAcknowledgements"),
        batchTechnicalAcknowledgements = batchTechnicalAcknowledgements ?: throw
            PulumiNullFieldException("batchTechnicalAcknowledgements"),
        needFunctionalAcknowledgement = needFunctionalAcknowledgement ?: throw
            PulumiNullFieldException("needFunctionalAcknowledgement"),
        needLoopForValidMessages = needLoopForValidMessages ?: throw
            PulumiNullFieldException("needLoopForValidMessages"),
        needTechnicalAcknowledgement = needTechnicalAcknowledgement ?: throw
            PulumiNullFieldException("needTechnicalAcknowledgement"),
        rolloverAcknowledgementControlNumber = rolloverAcknowledgementControlNumber ?: throw
            PulumiNullFieldException("rolloverAcknowledgementControlNumber"),
        sendSynchronousAcknowledgement = sendSynchronousAcknowledgement ?: throw
            PulumiNullFieldException("sendSynchronousAcknowledgement"),
    )
}
